#version 150
precision highp float;

uniform sampler2D texture;
uniform float specularExponent;

uniform sampler2D shadowMap;

in vec3 normalEyeSpace;
in vec3 lightDirEyeSpace;
in vec3 reflectionVectorEyeSpace;

in vec2 fragTexCoord;

in vec3 ambientColor;
in vec3 diffuseColor;
in vec3 specularColor;

in vec3 positionEyeSpace;

in vec3 fColor;

in vec4 smTexCoord;

in float fragEyespaceDepth;

out vec4 fragColor;
out float fragDepth;

void main()
{	
	vec3 ct, cf;
	vec4 texel;
	float intensity, at, af;

	vec3 n;
	vec3 R;
	vec3 E = normalize(-positionEyeSpace);
	float NdotL;
	float EdotR;

	cf = ambientColor;

	n = normalize(normalEyeSpace);
	
	NdotL = max(dot(n, normalize(lightDirEyeSpace)), 0.0);

	if (NdotL > 0.0) {
	
		cf += diffuseColor * NdotL;
		
		R = normalize(reflectionVectorEyeSpace);
		EdotR = max(dot(E, R), 0.0);
		cf += specularColor * pow(EdotR, specularExponent);
	}

	texel = texture2D(texture, fragTexCoord);
	ct = texel.rgb;
	
	// Apply shadows
	
	// note the perspective division!
	vec3 tex_coords = smTexCoord.xyz / smTexCoord.w;
	
	// read depth value from shadow map
	float depth = texture2D(shadowMap, tex_coords.xy).r;

	float inShadow;
	
	if (depth < tex_coords.z)
	{
		inShadow = float(0.3);
	} else
	{
		inShadow = float(1.0);
	}
	
	fragColor = inShadow * vec4(ct * cf, 1.0);
	
	//fragColor = vec4(fragColor.rgb, Blur);
	fragDepth = fragEyespaceDepth;
}