#version 150

precision highp float;

uniform mat4 projectionMatrix;
uniform mat4 viewingMatrix;
uniform mat4 modelMatrix;

uniform vec3 lightPos;
uniform mat4 textureMatrix;

uniform vec3 lightAmbientColor;
uniform vec3 lightDiffuseColor;
uniform vec3 lightSpecularColor;

uniform vec3 materialAmbientColor;
uniform vec3 materialDiffuseColor;
uniform vec3 materialSpecularColor;

uniform vec3 color;

in vec3 position;
in vec3 normal;
in vec2 texCoord;

out vec3 normalEyeSpace;
out vec3 lightDirEyeSpace;
out vec3 reflectionVectorEyeSpace;

out vec2 fragTexCoord;

out vec3 ambientColor;
out vec3 diffuseColor;
out vec3 specularColor;

out vec3 positionEyeSpace;

out vec3 fColor;

out vec4 smTexCoord;

//Variables for DOF
out float fragEyespaceDepth;

void main()
{
	vec4 vertex = vec4(position, 1.0);

	mat4 modelViewMatrix = viewingMatrix * modelMatrix;
	mat4 mvpMatrix = projectionMatrix * modelViewMatrix;
	
	vec3 globalAmbient = vec3(0.05, 0.05, 0.05);

	normalEyeSpace = normalize((modelViewMatrix * vec4(normal, 0.0)).xyz);

	lightDirEyeSpace = normalize(((viewingMatrix * vec4(lightPos, 1.0)) - (modelViewMatrix * vertex)).xyz);

	reflectionVectorEyeSpace = normalize(lightDirEyeSpace +  2 * ((dot(lightDirEyeSpace, normalEyeSpace) * normalEyeSpace) - lightDirEyeSpace));	
			
	ambientColor = globalAmbient + materialAmbientColor * lightAmbientColor;
	diffuseColor = materialDiffuseColor * lightDiffuseColor;
	specularColor = materialSpecularColor * lightSpecularColor;

	fragTexCoord = texCoord;

	positionEyeSpace = (modelViewMatrix * vertex).xyz;
	
	smTexCoord = textureMatrix * modelMatrix * vertex;
	
	gl_Position = mvpMatrix * vec4(position, 1.0);
	
	//FOR DOF
	fragEyespaceDepth = (modelViewMatrix * vertex).z;

	fColor = color;
}